==> digikam-2.1.1.tar.bz2: digikam-2.1.1/core/libs/dmetadata/metadatasettings.cpp <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2010-08-20
 * Description : central place for Metadata settings
 *
 * Copyright (C) 2010-2011 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include "metadatasettings.moc"

// Qt includes

#include <QApplication>
#include <QDir>
#include <QFileInfo>
#include <QMutex>

// KDE includes

#include <kconfig.h>
#include <kconfiggroup.h>
#include <kglobal.h>
#include <ksharedconfig.h>
#include <kdebug.h>

namespace Digikam
{

class MetadataSettings::MetadataSettingsPriv
{
public:

    MetadataSettingsPriv()
        : mutex(QMutex::Recursive),
          configGroup("Metadata Settings")
    {
    }

    MetadataSettingsContainer settings;
    QMutex                    mutex;

    const QString             configGroup;

public:

    MetadataSettingsContainer readFromConfig() const;
    void                      writeToConfig() const;
    MetadataSettingsContainer setSettings(const MetadataSettingsContainer& s);
};

MetadataSettingsContainer MetadataSettings::MetadataSettingsPriv::readFromConfig() const
{
    MetadataSettingsContainer s;
    KSharedConfig::Ptr config = KGlobal::config();
    KConfigGroup group        = config->group(configGroup);
    s.readFromConfig(group);
    return s;
}

void MetadataSettings::MetadataSettingsPriv::writeToConfig() const
{
    KSharedConfig::Ptr config = KGlobal::config();
    KConfigGroup group        = config->group(configGroup);
    settings.writeToConfig(group);
}

MetadataSettingsContainer MetadataSettings::MetadataSettingsPriv::setSettings(const MetadataSettingsContainer& s)
{
    QMutexLocker lock(&mutex);
    MetadataSettingsContainer old;
    old      = settings;
    settings = s;
    return old;
}

// -----------------------------------------------------------------------------------------------

class MetadataSettingsCreator
{
public:

    MetadataSettings object;
};

K_GLOBAL_STATIC(MetadataSettingsCreator, metatadaSettingsCreator)

// -----------------------------------------------------------------------------------------------

MetadataSettings* MetadataSettings::instance()
{
    return &metatadaSettingsCreator->object;
}

MetadataSettings::MetadataSettings()
    : d(new MetadataSettingsPriv)
{
    readFromConfig();
    qRegisterMetaType<MetadataSettingsContainer>("MetadataSettingsContainer");
}

MetadataSettings::~MetadataSettings()
{
    delete d;
}

MetadataSettingsContainer MetadataSettings::settings() const
{
    QMutexLocker lock(&d->mutex);
    MetadataSettingsContainer s(d->settings);
    return s;
}

bool MetadataSettings::exifRotate() const
{
    return d->settings.exifRotate;
}

void MetadataSettings::setSettings(const MetadataSettingsContainer& settings)
{
    MetadataSettingsContainer old = d->setSettings(settings);
    emit settingsChanged();
    emit settingsChanged(settings, old);
    d->writeToConfig();
}

void MetadataSettings::readFromConfig()
{
    MetadataSettingsContainer s   = d->readFromConfig();
    MetadataSettingsContainer old = d->setSettings(s);
    emit settingsChanged();
    emit settingsChanged(s, old);
}

}  // namespace Digikam

==> digikam-4.10.0.tar.bz2: digikam-4.10.0/core/libs/dmetadata/metadatasettings.cpp <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2010-08-20
 * Description : central place for Metadata settings
 *
 * Copyright (C) 2010-2013 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include "metadatasettings.moc"

// Qt includes

#include <QApplication>
#include <QDir>
#include <QFileInfo>
#include <QMutex>

// KDE includes

#include <kconfig.h>
#include <kconfiggroup.h>
#include <kglobal.h>
#include <ksharedconfig.h>
#include <kdebug.h>

namespace Digikam
{

class MetadataSettings::Private
{
public:

    Private()
        : mutex(QMutex::Recursive),
          configGroup("Metadata Settings")
    {
    }

    MetadataSettingsContainer settings;
    QMutex                    mutex;

    const QString             configGroup;

public:

    MetadataSettingsContainer readFromConfig() const;
    void                      writeToConfig() const;
    MetadataSettingsContainer setSettings(const MetadataSettingsContainer& s);
};

MetadataSettingsContainer MetadataSettings::Private::readFromConfig() const
{
    MetadataSettingsContainer s;
    KSharedConfig::Ptr config = KGlobal::config();
    KConfigGroup group        = config->group(configGroup);
    s.readFromConfig(group);
    return s;
}

void MetadataSettings::Private::writeToConfig() const
{
    KSharedConfig::Ptr config = KGlobal::config();
    KConfigGroup group        = config->group(configGroup);
    settings.writeToConfig(group);
}

MetadataSettingsContainer MetadataSettings::Private::setSettings(const MetadataSettingsContainer& s)
{
    QMutexLocker lock(&mutex);
    MetadataSettingsContainer old;
    old      = settings;
    settings = s;
    return old;
}

// -----------------------------------------------------------------------------------------------

class MetadataSettingsCreator
{
public:

    MetadataSettings object;
};

K_GLOBAL_STATIC(MetadataSettingsCreator, metatadaSettingsCreator)

// -----------------------------------------------------------------------------------------------

MetadataSettings* MetadataSettings::instance()
{
    return &metatadaSettingsCreator->object;
}

MetadataSettings::MetadataSettings()
    : d(new Private)
{
    readFromConfig();
    qRegisterMetaType<MetadataSettingsContainer>("MetadataSettingsContainer");
}

MetadataSettings::~MetadataSettings()
{
    delete d;
}

MetadataSettingsContainer MetadataSettings::settings() const
{
    QMutexLocker lock(&d->mutex);
    MetadataSettingsContainer s(d->settings);
    return s;
}

bool MetadataSettings::exifRotate() const
{
    return d->settings.exifRotate;
}

void MetadataSettings::setSettings(const MetadataSettingsContainer& settings)
{
    MetadataSettingsContainer old = d->setSettings(settings);
    emit settingsChanged();
    emit settingsChanged(settings, old);
    d->writeToConfig();
}

void MetadataSettings::readFromConfig()
{
    MetadataSettingsContainer s   = d->readFromConfig();
    MetadataSettingsContainer old = d->setSettings(s);
    emit settingsChanged();
    emit settingsChanged(s, old);
}

}  // namespace Digikam
